# Dataset of cortical activity recorded with high spatial resolution from anesthetized rats

## Summary

Here, we present an electrophysiological dataset recorded from the neocortex of twenty rats anesthetized with ketamine/xylazine. The wideband, spontaneous recordings were acquired with a single-shank silicon-based probe having 128 densely packed recording sites arranged in a 32x4 array. Using spike sorting, the activity of a total of 7126 single units was extracted from all layers of the cortex. Here, we share raw neural recordings, as well as spike times, extracellular spike waveforms and several properties of units packaged in a standardized electrophysiological data format. For technical validation of our dataset, we provide the distributions of derived single unit properties along with various spike sorting quality metrics.

## Downloading the data
## Repository structure

Each recording and corresponding metadata, single unit properties and quality metrics were packaged in the Neurodata Without Borders: Neurophysiology version 2.0 (NWB:N 2.0) data format using the MatNWB API. A single NWB file was created from each recording. NWB files were placed in the appropriate folder based on the identifier of the animal (from Rat01 to Rat20), insertion sequence (Insertion1 or Insertion2) and cortical depth (from Depth1 to Depth3). The filename of the NWB file (identifier) was constructed by concatenating the above information (e.g., Rat01_Insertion2_Depth3).
The NWB file contains several main groups which are similar to directories. The acquisition group contains the continuous wideband 128-channel data (‘wideband_multichannel_recording’) in a compressed form, as well as several parameters related to the raw data such as the measurement unit or the data conversion number. The general group contains metadata about the experiments and consists of several subgroups, related to the recording probe (‘general/devices’; ‘general/extracellular_ephys’) or the subjects of the experiments (‘general/subject’). Former subgroups carry information about the probe location (brain area and stereotaxic coordinates) and the relative positions and laminar location of recordings sites, while the latter contains metadata about the animal (e.g., sex, species, subject ID, or weight). Information about spike sorting and single units and corresponding data are available in the units group. For each unit, we included here the mean and standard deviation of their spike waveform on all channels, calculated both from the filtered (‘mean_waveform_all_channels_filt’; ’waveform_sd_all_channels_filt’) and the wideband data (‘mean_waveform_all_channels_raw’; ’ waveform_sd_all_channels_raw’). For an easier visualization of the spike waveform in two dimensions, we have also added an array which contains the mean spike waveform in the 32 x 4 shape of the array (‘mean_waveform_all_channels_filt_32x4’; ’mean_waveform_all_channels_raw_32x4’). Furthermore, the spike waveform recorded on the channel with the largest spike (i.e., peak waveform channel) was saved separately (‘mean_waveform_peak_channel_filt’, ‘mean_waveform_peak_channel_raw’). All single unit properties and cluster quality metrics described in the Methods section, as well as the spike times and spike count of each unit were saved in the units group. However, if needed, potential future users can use the provided wideband recordings to redo the spike sorting either by applying different parameters in Kilosort2 or using other spike sorting algorithms. Furthermore, to aid users in selecting and analyzing a subset of this dataset appropriate for the research goals, we also created an NWB file (‘allSingleUnits.nwb’) which contains all single unit with all the properties listed above, along with the identifier of the recording they originate from (‘units/session_id’).

## Related Publications
## Licensing


